<?php

namespace Acme\ParqueBundle\Controller;

use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Method;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Route;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Template;
use Acme\ParqueBundle\Entity\Individuos;
use Acme\ParqueBundle\Form\IndividuosType;
use Acme\ParqueBundle\Form\SearchType;

/**
 * Main controller.
 *
 * @Route("/parque")
 */
class MainController extends Controller
{
    /**
     * Lists all Individuos entities.
     *
     * @Route("/", name="home")
     * @Template()
     */
    public function indexAction()
    {
        // Create a search Form for indexpage just builder->add('','search');
        $form = $this->createForm(new IndividuosType());
        $form->bindRequest($this->getRequest());
        
        return $this->render('AcmeParqueBundle:Main:index.html.twig', array('form' => $form->createView()));
    }

    /**
     * Finds and displays a Individuos entity.
     *
     * @Route("/{id}/show", name="individuos_show")
     * @Template()
     */
    public function showAction($id)
    {
        $em = $this->getDoctrine()->getEntityManager();
        $entity = $em->getRepository('AcmeParqueBundle:Individuos')->find($id);

        if (!$entity) {
            throw $this->createNotFoundException('Unable to find Individuos entity.');
        }

        $deleteForm = $this->createDeleteForm($id);

        return $this->render('AcmeParqueBundle:Main:show.html.twig', array(
                                                                          'entity' => $entity,
                                                                          'delete_form' => $deleteForm->createView(),));
    }


    /**
     * Find/Show an Especie entity.
     *
     * @Route("/search", name="individuos_showby", defaults={"_format"="json"})
     * @Template("AcmeParqueBundle:Main:index.html.twig")
     */
    public function searchAction(Request $request)
    {
        // Get the request string
        $this->request = $request;
        $query = preg_replace('(\W)', '', trim($this->request->query->get('query')));

        // Make the query
        $em = $this->getDoctrine()->getEntityManager();
        $repos = $em->getRepository('AcmeParqueBundle:Individuos')->findAll();

        foreach ($repos as $entity) {
            $array[] = array('nombre' => $entity->getEspecie()->getNombreComun(), 'lat' => $entity->getLatitude(), 'lon' => $entity->getLongitude());
        }
        //JSON
        $response = new Response();
        $object = json_encode($array);

        // return response
        $response->setContent($object);
        return $response;

    }


    /**
     * AutoComplete Action
     *
     * @Route("/auto", name="autocomplete")
     *
     */
    public function autocompleteAction()
    {
        $em = $this->getDoctrine()->getEntityManager();

        $query = $this->getRequest()->query->get('term');
        $entities = $em->getRepository('AcmeParqueBundle:Especies')->search($query);

        foreach ($entities as $entity) {
            $array[] = $entity->getNombrecomun();
        }

        $response = new Response();
        $object = json_encode($array);

        $response->setContent($object);
        return $response;
    }

    /**
     * Displays a form to create a new Individuos entity.
     *
     * @Route("/new", name="individuos_new")
     * @Template()
     */
    public function newAction()
    {
        $entity = new Individuos();
        $form = $this->createForm(new IndividuosType(), $entity);

        return array(
            'entity' => $entity,
            'form' => $form->createView()
        );
    }

    /**
     * Creates a new Individuos entity.
     *
     * @Route("/create", name="individuos_create")
     * 
     * @Template("AcmeParqueBundle:Individuos:new.html.twig")
     */
    public function createAction()
    {
        $entity = new Individuos();
        $request = $this->getRequest();
        $form = $this->createForm(new IndividuosType(), $entity);
        $form->bindRequest($request);

        if ($form->isValid()) {
            $em = $this->getDoctrine()->getEntityManager();
            $em->persist($entity);
            $em->flush();

            return $this->redirect($this->generateUrl('individuos_show', array('id' => $entity->getId())));

        }

        return $this->render('AcmeParqueBundle:Parque:new.html.twig', array(
                                                                           'entity' => $entity,
                                                                           'form' => $form->createView()
                                                                      ));
    }

    /**
     * Displays a form to edit an existing Individuos entity.
     *
     * @Route("/{id}/edit", name="individuos_edit")
     * @Template()
     */
    public function editAction($id)
    {
        $em = $this->getDoctrine()->getEntityManager();

        $entity = $em->getRepository('AcmeParqueBundle:Individuos')->find($id);

        if (!$entity) {
            throw $this->createNotFoundException('Unable to find Individuos entity.');
        }

        $editForm = $this->createForm(new IndividuosType(), $entity);
        $deleteForm = $this->createDeleteForm($id);

        return array(
            'entity' => $entity,
            'edit_form' => $editForm->createView(),
            'delete_form' => $deleteForm->createView(),
        );
    }

    /**
     * Edits an existing Individuos entity.
     *
     * @Route("/{id}/update", name="individuos_update")
     * @Method("post")
     * @Template("AcmeParqueBundle:Individuos:edit.html.twig")
     */
    public function updateAction($id)
    {
        $em = $this->getDoctrine()->getEntityManager();

        $entity = $em->getRepository('AcmeParqueBundle:Individuos')->find($id);

        if (!$entity) {
            throw $this->createNotFoundException('Unable to find Individuos entity.');
        }

        $editForm = $this->createForm(new IndividuosType(), $entity);
        $request = $this->getRequest();

        $editForm->bindRequest($request);

        if ($editForm->isValid()) {
            $em->persist($entity);
            $em->flush();

            return $this->redirect($this->generateUrl('individuos_edit', array('id' => $id)));
        }

        return $this->render('AcmeParqueBundle:Main:edit.html.twig', array(
                                                                                'entity' => $entity,
                                                                                'edit_form' => $editForm->createView(),
                                                                           ));
    }

    /**
     * Deletes a Individuos entity.
     *
     * @Route("/{id}/delete", name="individuos_delete")
     * @Method("post")
     */
    public function deleteAction($id)
    {
        $form = $this->createDeleteForm($id);
        $request = $this->getRequest();

        $form->bindRequest($request);

        if ($form->isValid()) {
            $em = $this->getDoctrine()->getEntityManager();
            $entity = $em->getRepository('AcmeParqueBundle:Individuos')->find($id);

            if (!$entity) {
                throw $this->createNotFoundException('Unable to find Individuos entity.');
            }

            $em->remove($entity);
            $em->flush();
        }

        return $this->redirect($this->generateUrl('individuos'));
    }

    private function createDeleteForm($id)
    {
        return $this->createFormBuilder(array('id' => $id))
                ->add('id', 'hidden')
                ->getForm();
    }


}
